@@ -120,7 +120,7 @@ entry_key_press_event_cb (GtkWidget *entry,
 {
   LogviewFindbar *findbar = user_data;
 
-  if (event->keyval == GDK_Escape) {
+  if (event->keyval == GDK_KEY_Escape) {
     g_signal_emit (findbar, signals[CLOSE], 0);
     return TRUE;
   }
@@ -146,7 +146,7 @@ unbold_timeout_cb (gpointer user_data)
 static void 
 logview_findbar_init (LogviewFindbar *findbar)
 {
-  GtkWidget *label, *button, *w, *box;
+  GtkWidget *label, *w, *box;
   GtkToolbar *gtoolbar;
   GtkToolItem *item;
   LogviewFindbarPrivate *priv;
@@ -345,4 +345,4 @@ logview_findbar_set_message (LogviewFindbar *findbar,
                       text != NULL ? text : "");
   g_object_set (findbar->priv->separator, "visible", text != NULL, NULL);
   g_object_set (findbar->priv->status_item, "visible", text != NULL, NULL);
-}
\ No newline at end of file
+}
